@@ -3,6 +3,7 @@ from django.utils.safestring import mark_safe
 from django.utils.html import escape
 import re
 from django.template import Node
+from django.utils.encoding import smart_str, smart_unicode
 
 register = template.Library()
 rx = re.compile(r'(%(\([^\s\)]*\))?[sd])')
@@ -36,6 +37,28 @@ def gt(a,b):
 gt=register.filter(gt)
 
 
+def do_incr(parser, token):
+    args = token.split_contents()
+    if len(args) < 2:
+        raise TemplateSyntaxError("'incr' tag requires at least one argument")
+    name = args[1]
+    if not hasattr(parser, '_namedIncrNodes'):
+        parser._namedIncrNodes = {}
+    if not name in parser._namedIncrNodes:
+        parser._namedIncrNodes[name] = IncrNode(0)
+    return parser._namedIncrNodes[name]
+do_incr = register.tag('increment', do_incr)
+
+
+class IncrNode(template.Node):
+   def __init__(self, init_val=0):
+       self.val = init_val
+
+   def render(self, context):
+       self.val += 1
+       return smart_unicode(self.val)
+       
+    
 def is_fuzzy(message):
     return message and hasattr(message, 'flags') and 'fuzzy' in message.flags
 is_fuzzy = register.filter(is_fuzzy)
